==> apper_0.7.2.orig.tar.bz2: apper-0.7.2/Apper/BackendDetails.h <==
/***************************************************************************
 *   Copyright (C) 2009-2011 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef BACKEND_DETAILS_H
#define BACKEND_DETAILS_H

#include <KDialog>

#include "ui_BackendDetails.h"

class BackendDetails : public KDialog, public Ui::BackendDetails
{
Q_OBJECT

public:
    BackendDetails(QWidget *parent = 0);
};

#endif

==> apper-0.8.0.tar.bz2: apper-0.8.0/Apper/BackendDetails.h <==
/***************************************************************************
 *   Copyright (C) 2009-2013 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef BACKEND_DETAILS_H
#define BACKEND_DETAILS_H

#include <KDialog>

namespace Ui {
    class BackendDetails;
}

class BackendDetails : public KDialog
{
    Q_OBJECT
public:
    explicit BackendDetails(QWidget *parent = 0);
    ~BackendDetails();

private:
    Ui::BackendDetails *ui;
};

#endif
